pkmn-colosseum decompilation progress · ByteMatchpkmn-colosseum is 12.79% decompiled
0.00% fully linked · GameCube
Code (2.50 MB)
Matched12.79% · 319,056 of 2,495,108 bytes (319.06 KB)Fuzzy match27.80% · ≈693,649 of 2,495,108 bytes (693.65 KB), counting partly matched code Fully linked 0.00%
Fully linked
0.00% · 0 of 2,495,108 bytes (0 B)
Matched 12.79%Matched12.79% · 319,056 of 2,495,108 bytes (319.06 KB)
Fuzzy match 27.80%Fuzzy match27.80% · ≈693,649 of 2,495,108 bytes (693.65 KB), counting partly matched code
Data (2.20 MB)
Matched0.77% · 16,933 of 2,196,256 bytes (16.93 KB) Fully linked 0.00%Fully linked0.00% · 0 of 2,196,256 bytes (0 B)Matched 0.77%Matched0.77% · 16,933 of 2,196,256 bytes (16.93 KB)
795c2f5 | README: progress update
· No unit breakdown is stored for this commit (it came from decomp.dev's history, which keeps totals only).
Merge pull request #664: verified 97.44 percent source data